@@ -8,13 +8,13 @@ Catalyst::Plugin::Log::Handler - Catalyst Plugin for Log::Handler
 
 =head1 VERSION
 
-Version 0.07_01 (developer release)
+Version 0.01
 
 =cut
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.01';
 
-use MRO::Compat;
+use NEXT;
 
 sub setup {
     my $c = shift;
@@ -23,7 +23,7 @@ sub setup {
 
     $c->log((__PACKAGE__ . '::Backend')->new($config));
 
-    return $c->maybe::next::method(@_);
+    return $c->NEXT::setup(@_);
 }
 
 
@@ -31,15 +31,14 @@ package Catalyst::Plugin::Log::Handler::Backend;
 use strict;
 use warnings;
 use base qw(Class::Accessor::Fast);
-use Log::Handler 0.63;
-use MRO::Compat;
+use Log::Handler 0.11;
 
-__PACKAGE__->mk_accessors(qw(handler));
+__PACKAGE__->mk_accessors(qw(_handler));
 
 my %cat_to_handler_level = (
     debug => 'debug',
     info  => 'info',
-    warn  => 'warning',
+    warn  => 'warn',
     error => 'error',
     fatal => 'emergency',
 );
@@ -48,28 +47,28 @@ my %cat_to_handler_level = (
 
     while (my ($catlevel, $handlerlevel) = each %cat_to_handler_level) {
 
-	my $logsub = sub {
-            my $self = shift;
-
-	    $self->handler->$handlerlevel(@_);
-        };
-
-	my $handlerfunc = "is_$handlerlevel";
-        my $testsub = sub {
-            my $self = shift;
-
-	    $self->handler->$handlerfunc();
-        };
-
 	no strict 'refs';
-        *{$catlevel}      = $logsub;
-        *{"is_$catlevel"} = $testsub;
+
+	*{$catlevel} = sub {
+	    use strict;
+            my $self = shift;
+
+	    $self->_handler->$handlerlevel(@_);
+        };
+
+	my $handlerfunc = "would_log_$handlerlevel";
+        *{"is_$catlevel"} = sub {
+	    use strict;
+            my $self = shift;
+
+	    $self->_handler->$handlerfunc();
+        };
     }
 }
 
 sub new {
     my $class = shift;
-    my $self  = $class->next::method();
+    my $self  = $class->SUPER::new;
 
     my ($config) = @_;
 
@@ -81,11 +80,11 @@ sub new {
     # Log::Handler->new will fail if there's no filename in the conf.  But let's
     # try it anyway to convince the user.
 
-    $self->handler(Log::Handler->new( file => {
+    $self->_handler(Log::Handler->new(
 	minlevel => 0,
 	maxlevel => 7,
 	%$config,
-    } ));
+    ));
     return $self;
 }
 
@@ -101,20 +100,10 @@ __END__
 Catalyst configuration (e. g. in YAML format):
 
     Log::Handler:
-        file:
-            filename: /var/log/myapp.log
-            fileopen: 1
-            mode: append
-            newline: 1
-
-To log a message:
-
-    $c->log->debug('Greetings from the people of earth');
-    $c->log->info ('This is an info message.');
-    $c->log->warn ('This is the last warning.');
-    $c->log->error('This is an error message.');
-    $c->log->fatal('This is a fatal message.');
-    $c->handler->crit('This is a critical message.');
+        filename: /var/log/myapp.log
+        fileopen: 1
+        mode: append
+        newline: 1
 
 =head1 DESCRIPTION
 
@@ -134,21 +123,13 @@ This module is a wrapper for said L<Log::Handler>.
 =head2 debug, info, warn, error, fatal
 
 These methods map to the L<Log::Handler> methods with the same name, except
-for fatal, which maps to emergency, and warn, which maps to warning.  This is
-because L<Catalyst> and L<Log::Handler> don't use the same names for log
-levels.
+for fatal, which maps to emergency.  This is because L<Catalyst> and
+L<Log::Handler> don't use the same names for log levels.
 
-To log a message with a level that is no common Catalyst log level, you can
-use the handler method (see SYNOPSIS).
+=head2 is_debug, is_info, ...
 
-=head2 is_debug, is_info, is_warn, is_error, is_fatal
-
-These methods map to the L<Log::Handler> methods is_debug, is_info, is_warning,
-is_error, is_emergency, respectively.
-
-=head2 handler
-
-Returns the L<Log::Handler> object.
+These methods map to the L<Log::Handler> methods would_log_debug,
+would_log_info, ...
 
 =head1 CONFIGURATION
 
@@ -158,25 +139,9 @@ configuration at the beginning of this document is very well-suited for a
 Catalyst application.  (Except for the file name, of course.)
 
 To be consistent with L<Catalyst::Log>, the options minlevel and maxlevel
-default to 0 and 7, respectively, i. e. all messages are logged.  The other
-defaults are not touched.
+default to 0 and 7, respectively.  The other defaults are not touched.
 
 If you use L<Catalyst::Plugin::ConfigLoader>,
 please load this module after L<Catalyst::Plugin::ConfigLoader>.
 
-=head1 AUTHOR
-
-Christoph Bussenius <pepe(at)cpan.org>
-
-If you use this module, I'll be glad if you drop me a note.
-You should mention this module's name (or the short form CPLH) in the subject
-of your mails, in order to make sure they won't get lost in all the spam.
-
-=head1 COPYRIGHT
-
-Copyright (C) 2007,2010 Christoph Bussenius.
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =cut
